{% extends "wagtailadmin/base.html" %}
{% load i18n %}
{% block titletag %}{% trans "Trash Can" %}{% endblock %}

{% block extra_js %}
    {% include "wagtailadmin/pages/_editor_js.html" %}

    {{ form.media }}
{% endblock %}

{% block content %}
    {% trans "Restore page to new location" as header_title %}
    {% include "wagtailadmin/shared/header.html" with title=header_title icon="redirect" %}

    <div class="nice-padding">
        <div class="help-block help-info">
            {% blocktrans %}
                <p>
                Choose a destination where the page will be restored to
                </p>
            {% endblocktrans %}
        </div>
    </div>

    {% include "wagtailadmin/shared/non_field_errors.html" %}

    <form action="" method="POST" class="nice-padding" novalidate enctype="multipart/form-data">
        {% csrf_token %}

        <ul class="fields">
            {% for field in form.visible_fields %}
                {% include "wagtailadmin/shared/field_as_li.html" %}
            {% endfor %}

            <li>
                <input type="submit" value="{% trans 'Restore' %}" class="button" />
            </li>
        </ul>
    </form>
{% endblock %}
