{% extends "modeladmin/index.html" %}
{% load i18n modeladmin_tags wagtailadmin_tags %}

{% block result_list %}
    {% if not all_count %}
        <div class="nice-padding" style="margin-top:30px;">
            <p>{% blocktrans with view.verbose_name_plural as name %}Your trash can is empty.{% endblocktrans %}</p>
        </div>
    {% else %}
        {% result_list %}
    {% endif %}
{% endblock %}
